==> haskell-data-textual-0.3.0.2-87-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-textual
version: 0.3.0.2
id: data-textual-0.3.0.2-1xRErGBLtmmDz01SmaOsPy
key: data-textual-0.3.0.2-1xRErGBLtmmDz01SmaOsPy
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-textual
synopsis: Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.
category: Data, Text
abi: 27538c4e623ac94421040a1f824fdced
exposed: True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral
import-dirs: /usr/lib/ghc-8.6.4/site-local/data-textual-0.3.0.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/data-textual-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/data-textual-0.3.0.2
hs-libraries: HSdata-textual-0.3.0.2-1xRErGBLtmmDz01SmaOsPy
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    parsers-0.12.9-K7LlZXV3pbK4BtaJ1E8WMh text-1.2.3.1
    text-latin1-0.3.1-9Jk52ccaV4CGspJYZunZZU
    text-printer-0.5-EEnxSm7ih2F3Cat1XqaxzY
haddock-interfaces: /usr/share/doc/haskell-data-textual/html/data-textual.haddock
haddock-html: /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-textual-0.3.0.2-88-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-textual
version: 0.3.0.2
id: data-textual-0.3.0.2-Cjcf40gsbjTFOBsKiPd1di
key: data-textual-0.3.0.2-Cjcf40gsbjTFOBsKiPd1di
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-textual
synopsis: Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.
category: Data, Text
abi: fded75676ee4bb8cfcaf5ebde646b368
exposed: True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral
import-dirs: /usr/lib/ghc-8.6.4/site-local/data-textual-0.3.0.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/data-textual-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/data-textual-0.3.0.2
hs-libraries: HSdata-textual-0.3.0.2-Cjcf40gsbjTFOBsKiPd1di
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    parsers-0.12.9-8kHnM8CSNK1Ggoz6JyepHW text-1.2.3.1
    text-latin1-0.3.1-9Jk52ccaV4CGspJYZunZZU
    text-printer-0.5-EEnxSm7ih2F3Cat1XqaxzY
haddock-interfaces: /usr/share/doc/haskell-data-textual/html/data-textual.haddock
haddock-html: /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
